
#ifndef USQLCCLIENT
#define USQLCCLIENT


typedef struct{
	int seclevel;
	int sock;
	int timeout;
	int clientID;
	fd_set srefs;
}uSQLCdb;

// The uSQLite server inicates the size of data in the argv array if they are more
// than 32 chars. This client passes that info in the fsizes arg added to the callback
// (it gives **all** field sizes, using strlen on shorter fields).
typedef int (*DatCallBack)(void *, int argc, char **argv, char **ColName,int fsizes[]) ;
typedef void (*ErrCallBack)(char *) ;

enum uSQLCdbErrs{
	uSQLCerrNONE=0,
	uSQLCerrMALLOC=1,   // Any problems allocating memory
	uSQLCerrSOCK=2,     // Failure opening socket
	uSQLCerrNAME=3,     // Failed to resolve name
	uSQLCerrCON=4,      // Error connecting socket;
	uSQLCerrRESP=5,     // timeout waiting for response from opened socket or during login
	uSQLCerrTEXEC=6,    // timeout during an exec
	uSQLCerrERR=7,      // At least one error record recieved during exec.
	uSQLCerrFORM=8,     // Records arrived in strange order, aborted
	uSQLCerrSYNTAX=9,   // Syntax error in recieved record, aborted
	uSQLCerrHSZ=10,     // Column header size out of range, aborted
};

// Opens up a connection to a uSQLdb server. On success returns a pointer
// to a uSQLdb structure. On failure returns NULL, ErrCode may have been
// set to give some idea for the failure reason.
uSQLCdb *uSQLCopen(char *user,char *pass,char *server,int port,int timeout,int *ErrCode);

// Closes a connection and frees up any memory allocated.
void uSQLCclose(uSQLCdb *udb);

// Set timeout for the operations, initially set to the value passed at open, but
// this will be set to an appropriate time for opening a connection to a database.
// You may vary this time for subsequent operations.
// BTW, timeout times are in mS, are approximate, and may have a resolution less
// than 1mS. The smallest value > requested value will be used. See the waitRX
// local function to make things clearer ;-)
void uSQLCtimeouts(uSQLCdb *udb,int timeouts);

// Send a query string to the server... mimics SQLite's exec command except that
// error messages are sent to the error callback function and the record callback
// has an extra parameter which points to a list of the size of the data fields.
// Normally returns uSQLCerrNONE or uSQLCerrERR if an error record
// had been recieved. Other error codes mean there is a serious problem
// and you should probably close the connection.
int uSQLCexec(uSQLCdb *udb,char *sql,DatCallBack,void *tag,ErrCallBack);


#endif
