// chink is a dynamic buffer designed to grow in dribs and drabs
// and then reset. It reallocs in CHINKBLOK sizes which, if you
// wanted to optimize would probably be best done on the basis
// of the platforms memory handling characteristics.

#ifndef CHINK_H
#define CHINK_H

#define CHINKBLOK 1024

typedef struct{
	char *ch;
	int allocated;
	int len;
	int maxsize;
	char tr;
	char tn;
}Chink;

// Make a new empty Chink
Chink *ChinkMake(int maxsize);

// Destroy a Chink
void ChinkDestroy(Chink *ck);

// Clear contents
void ChinkReset(Chink *ck);

// Add data, return new len or -1 if allocate error
int ChinkAdd(Chink *ck,char *data,int len);

// Make sure buffer can accept maxsize, returns space available or -1 for err
int ChinkBuffFor(Chink *ck,int maxsize);

// Returns char* to insert point
char *ChinkIns(Chink *ck);

// Return len of first line or 0 if no line break char (excludes break chars)
// ChinkBreak will also strip any leading line break chars
int ChinkBreak(Chink *ck);

// Remake removing consume chars at start, returns len.
// Will also strip up to 2 line break chars **after** consumed bytes
// Will pack resultant data (attempts to free unused memory), can be called
// with 0 to just pack.
// Returns new length
int ChinkConsume(Chink *ck,int consume);




	


#endif
